﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Windows.Threading;

namespace xamDataChart_Sync
{
    public class ObservableModel : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        protected void NotifyPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }

    public class MainWindowViewModel : ObservableModel
    {
        private LineSeriesSampleData _ChartData = new LineSeriesSampleData();
        public LineSeriesSampleData ChartData
        {
            get { return _ChartData; }
            set { _ChartData = value; NotifyPropertyChanged("ChartData"); }
        }

        private double _MinimumValue = 0;
        public double MinimumValue
        {
            get { return _MinimumValue; }
            set { _MinimumValue = value; NotifyPropertyChanged("MinimumValue"); }
        }

        private double _MaximumValue = 10;
        public double MaximumValue
        {
            get { return _MaximumValue; }
            set { _MaximumValue = value; NotifyPropertyChanged("MaximumValue"); }
        }
    }

    public class LineSeriesSampleData : ObservableCollection<LineSeriesDataPoint>
    {
        private Random randomValueGenerator = new Random();

        public LineSeriesSampleData()
        {
            Add(new LineSeriesDataPoint() { Value = 1, Label = "Data Point 1" });
            Add(new LineSeriesDataPoint() { Value = 2, Label = "Data Point 2" });
            Add(new LineSeriesDataPoint() { Value = 3, Label = "Data Point 3" });
            Add(new LineSeriesDataPoint() { Value = 4, Label = "Data Point 4" });
            Add(new LineSeriesDataPoint() { Value = 5, Label = "Data Point 5" });

            // Timer to update the data.
            DispatcherTimer _timer = new DispatcherTimer();
            _timer.Interval = new TimeSpan(0, 0, 1);
            _timer.Tick += LiveData;
            _timer.Start();
        }

        private void LiveData(object sender, EventArgs e)
        {
            LineSeriesDataPoint data = new LineSeriesDataPoint()
            {
                Value = randomValueGenerator.Next(0, 10),
                Label = "Data Point " + Count + 1,
            };

            Add(data);
        }
    }

    public class LineSeriesDataPoint : ObservableModel
    {
        #region Fields
        private int _value;
        private string _label;
        #endregion

        #region Properties
        public int Value
        {
            get { return _value; }
            set
            {
                if (_value != value)
                {
                    _value = value;
                    NotifyPropertyChanged("Value");
                }
            }
        }
        public string Label
        {
            get { return _label; }
            set
            {
                if (_label != value)
                {
                    _label = value;
                    NotifyPropertyChanged("Label");
                }
            }
        }
        #endregion
    }
}
